@@ -2,7 +2,9 @@
 
 import cgi
 import json
+import logging
 import urllib
+import pprint
 try:
     from urllib import urlencode
 except ImportError:
@@ -13,10 +15,19 @@ except ImportError:
     import urllib.parse as urlparse # renamed in python3
 
 import sanction
+from pyramid.threadlocal import get_current_registry
 from zope.interface import implementer
 
 from .interfaces import *
 
+
+logger = logging.getLogger('openstax-accounts')
+
+
+class UserNotFoundException(Exception):
+    pass
+
+
 # A json parser for data returned from a request_token request because sanction
 # does not work with a null expires_in
 def parser_remove_null_expires_in(data):
@@ -25,8 +36,19 @@ def parser_remove_null_expires_in(data):
         data.pop('expires_in')
     return data
 
-class UserNotFoundException(Exception):
-    pass
+
+@implementer(IMessageSender)
+def send_message(msg_data):
+    """Send the message using the accounts request."""
+    accounts = get_current_registry().getUtility(IOpenstaxAccounts)
+    accounts.request('/api/messages.json', data=urlencode(msg_data, True))
+
+
+@implementer(IMessageSender)
+def log_message(msg_data):
+    """Log the message to the local logger."""
+    msg_data_as_str = pprint.pformat(msg_data)
+    logger.info("Captured message:\n\n{}".format(msg_data_as_str))
 
 
 @implementer(IOpenstaxAccounts)
@@ -94,7 +116,7 @@ class OpenstaxAccounts(object):
         return self.request('/api/users.json?{}'.format(
             urlencode({'q': query})))
 
-    def send_message(self, username, subject, body):
+    def send_message(self, username, subject, text_body, html_body=None):
         users = self.global_search('username:{}'.format(username))
         userid = None
         for user in users['users']:
@@ -103,14 +125,20 @@ class OpenstaxAccounts(object):
         if userid is None:
             raise UserNotFoundException('User "{}" not found'.format(username))
 
-        self.request('/api/messages.json', data=urlencode({
-                     'user_id': int(userid),
-                     'to[user_ids][]': [int(userid)],
-                     'subject': subject,
-                     'body[text]': body,
-                     'body[html]': '<html><body>{}</body></html>'.format(
-                         cgi.escape(body)),
-                     }, True))
+        if html_body is None:
+            html_body = '<html><body>{}</body></html>'.format(
+                cgi.escape(text_body).replace('\n', '\n<br/>'))
+
+        msg_data = {
+            'user_id': int(userid),
+            'to[user_ids][]': [int(userid)],
+            'subject': subject,
+            'body[text]': text_body,
+            'body[html]': html_body,
+            }
+
+        send_msg_util = get_current_registry().getUtility(IMessageSender)
+        send_msg_util(msg_data)
 
     def get_profile(self):
         return self.request('/api/user.json')
@@ -150,6 +178,13 @@ def main(config):
     OpenstaxAccounts.application_secret = settings['openstax_accounts.application_secret']
     OpenstaxAccounts.application_url = settings['openstax_accounts.application_url']
 
+    # Configure a message sending utility.
+    msg_sending_util = {
+        'default': send_message,
+        'log': log_message,
+        }[settings.get('openstax_accounts.message_sender', 'default')]
+    config.registry.registerUtility(msg_sending_util, IMessageSender)
+
     openstax_accounts = OpenstaxAccounts()
     openstax_accounts.request_application_token()
     config.registry.registerUtility(openstax_accounts, IOpenstaxAccounts)
